/*! UIkit 2.14.0 | http://www.getuikit.com | (c) 2014 YOOtheme | MIT License */
(function ($, UI) {

    "use strict";

    var $win = UI.$win,
        $doc = UI.$doc,
        scrollspies = [],
        checkScrollSpy = function () {
            for (var i = 0; i < scrollspies.length; i++) {
                UI.support.requestAnimationFrame.apply(window, [scrollspies[i].check]);
            }
        };

    UI.component('scrollspy', {

        defaults: {
            "cls": "@-scrollspy-inview",
            "initcls": "@-scrollspy-init-inview",
            "topoffset": 0,
            "leftoffset": 0,
            "repeat": false,
            "delay": 0
        },

        boot: function () {

            // listen to scroll and resize
            $doc.on("scrolling.uk.document", checkScrollSpy);
            $win.on("resize orientationchange", UI.Utils.debounce(checkScrollSpy, 50));

            // init code
            UI.ready(function (context) {

                UI.$("[data-@-scrollspy]", context).each(function () {

                    var element = UI.$(this);

                    if (!element.data("scrollspy")) {
                        var obj = UI.scrollspy(element, UI.Utils.options(element.attr("data-@-scrollspy")));
                    }
                });
            });
        },

        init: function () {


            var $this = this, idle, inviewstate, initinview,
                fn = function () {

                    var inview = UI.Utils.isInView($this.element, $this.options);

                    if (inview && !inviewstate) {

                        if (idle) clearTimeout(idle);

                        if (!initinview) {
                            $this.element.addClass($this.options.initcls);
                            $this.offset = $this.element.offset();
                            initinview = true;

                            $this.trigger("init.uk.scrollspy");
                        }

                        idle = setTimeout(function () {

                            if (inview) {
                                $this.element.addClass("@-scrollspy-inview").addClass($this.options.cls).width();
                            }
                        }, $this.options.delay);

                        inviewstate = true;
                        $this.trigger("inview.uk.scrollspy");
                    }

                    if (!inview && inviewstate && $this.options.repeat) {
                        $this.element.removeClass("@-scrollspy-inview").removeClass($this.options.cls);
                        inviewstate = false;

                        $this.trigger("outview.uk.scrollspy");
                    }
                };

            fn();

            this.check = fn;
            scrollspies.push(this);
        }
    });


    var scrollspynavs = [],
        checkScrollSpyNavs = function () {
            for (var i = 0; i < scrollspynavs.length; i++) {
                UI.support.requestAnimationFrame.apply(window, [scrollspynavs[i].check]);
            }
        };

    UI.component('scrollspynav', {

        defaults: {
            "cls": '@-active',
            "closest": false,
            "topoffset": 0,
            "leftoffset": 0,
            "smoothscroll": false
        },

        boot: function () {

            // listen to scroll and resize
            $doc.on("scrolling.uk.document", checkScrollSpyNavs);
            $win.on("resize orientationchange", UI.Utils.debounce(checkScrollSpyNavs, 50));

            // init code
            UI.ready(function (context) {

                UI.$("[data-@-scrollspy-nav]", context).each(function () {

                    var element = UI.$(this);

                    if (!element.data("scrollspynav")) {
                        var obj = UI.scrollspynav(element, UI.Utils.options(element.attr("data-@-scrollspy-nav")));
                    }
                });
            });
        },

        init: function () {

            var ids = [],
                links = this.find("a[href^='#']").each(function () {
                    ids.push($(this).attr("href"));
                }),
                targets = $(ids.join(",")),

                clsActive = UI.prefix(this.options.cls),
                clsClosest = UI.prefix(this.options.closest || this.options.closest);

            var $this = this, inviews, fn = function () {

                inviews = [];

                for (var i = 0; i < targets.length; i++) {
                    if (UI.Utils.isInView(targets.eq(i), $this.options)) {
                        inviews.push(targets.eq(i));
                    }
                }

                if (inviews.length) {

                    var navitems,
                        scrollTop = $win.scrollTop(),
                        target = (function () {
                            for (var i = 0; i < inviews.length; i++) {
                                if (inviews[i].offset().top >= scrollTop) {
                                    return inviews[i];
                                }
                            }
                        })();

                    if (!target) return;

                    if ($this.options.closest) {
                        links.closest(clsClosest).removeClass(clsActive);
                        navitems = links.filter("a[href='#" + target.attr("id") + "']").closest(clsClosest).addClass(clsActive);
                    } else {
                        navitems = links.removeClass(clsActive).filter("a[href='#" + target.attr("id") + "']").addClass(clsActive);
                    }

                    $this.element.trigger("inview.uk.scrollspynav", [target, navitems]);
                }
            };

            if (this.options.smoothscroll && UI.smoothScroll) {
                links.each(function () {
                    UI.smoothScroll(this, $this.options.smoothscroll);
                });
            }

            fn();

            this.element.data("scrollspynav", this);

            this.check = fn;
            scrollspynavs.push(this);

        }
    });

})(jQuery, UIkit);
